@@ -28,9 +28,19 @@
 #include <QSet>
 #include <QString>
 
+void initEnvironment()
+{
+    // We need the default locale to be English otherwise the brokenTags test fails
+    // since the "Opening and ending tag mismatch" text comes from Qt
+    qputenv("LANG", "en_US.utf8");
+    QStandardPaths::setTestModeEnabled(true);
+}
+
+Q_CONSTRUCTOR_FUNCTION(initEnvironment)
+
 void KLocalizedStringTest::initTestCase()
 {
-    KLocalizedString::setApplicationDomain("ki18n-test");
+    KLocalizedString::setApplicationDomain(QByteArrayLiteral("ki18n-test"));
 
     m_hasFrench = true;
     m_hasCatalan = true;
@@ -64,7 +74,8 @@ void KLocalizedStringTest::initTestCase()
         m_hasCatalan = compileCatalogs({QFINDTESTDATA("po/ca/ki18n-test.po")}, dataDir, "ca");
     }
     if (m_hasFrench) {
-        qputenv("XDG_DATA_DIRS", qgetenv("XDG_DATA_DIRS") + ":" + QFile::encodeName(dataDir.path()));
+        const QByteArray dataDirs = qgetenv("XDG_DATA_DIRS") + ":" + QFile::encodeName(dataDir.path());
+        qputenv("XDG_DATA_DIRS", dataDirs);
         // bind... dataDir.path()
         QStringList languages;
         languages.append("fr");
@@ -401,31 +412,6 @@ void KLocalizedStringTest::translateToFrench()
     QCOMPARE(i18n("Job"), QString::fromUtf8("Tâche"));
 }
 
-#if KI18N_ENABLE_DEPRECATED_SINCE(5, 0)
-void KLocalizedStringTest::translateQt()
-{
-    KLocalizedString::insertQtDomain("ki18n-test-qt");
-    QString result = KLocalizedString::translateQt("QPrintPreviewDialog", "Landscape", nullptr, 0);
-    // When we use the default language, translateQt returns an empty string.
-    QString expected = m_hasFrench ? QString("Paysage") : QString();
-    QCOMPARE(result, expected);
-#if 0 // KLocalizedString no longer does anything with QTranslator, this needed?
-    result = QCoreApplication::translate("QPrintPreviewDialog", "Landscape");
-    QString expected2 = m_hasFrench ? QString("Paysage") : QString("Landscape");
-    QCOMPARE(result, expected2);
-#endif
-
-#if 0 // translateRaw no longer public, this needed?
-    // So let's use translateRaw instead for the threaded test
-    QString lang;
-    KLocale::global()->translateRaw("Landscape", &lang, &result);
-    QCOMPARE(lang, m_hasFrench ? QString("fr") : QString("en_US"));
-    QCOMPARE(result, m_hasFrench ? QString("Paysage") : QString("Landscape"));
-#endif
-    KLocalizedString::removeQtDomain("ki18n-test-qt");
-}
-#endif
-
 void KLocalizedStringTest::testLocalizedTranslator()
 {
     if (!m_hasFrench) {
@@ -520,21 +506,10 @@ void KLocalizedStringTest::testThreads()
 {
     QThreadPool::globalInstance()->setMaxThreadCount(10);
     QFutureSynchronizer<void> sync;
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
     sync.addFuture(QtConcurrent::run(&KLocalizedStringTest::correctSubs, this));
     sync.addFuture(QtConcurrent::run(&KLocalizedStringTest::correctSubs, this));
     sync.addFuture(QtConcurrent::run(&KLocalizedStringTest::correctSubs, this));
     sync.addFuture(QtConcurrent::run(&KLocalizedStringTest::translateToFrench, this));
-#else
-    sync.addFuture(QtConcurrent::run(this, &KLocalizedStringTest::correctSubs));
-    sync.addFuture(QtConcurrent::run(this, &KLocalizedStringTest::correctSubs));
-    sync.addFuture(QtConcurrent::run(this, &KLocalizedStringTest::correctSubs));
-    sync.addFuture(QtConcurrent::run(this, &KLocalizedStringTest::translateToFrench));
-#endif
-#if KI18N_ENABLE_DEPRECATED_SINCE(5, 0)
-    sync.addFuture(QtConcurrent::run(this, &KLocalizedStringTest::translateQt));
-    sync.addFuture(QtConcurrent::run(this, &KLocalizedStringTest::translateQt));
-#endif
     sync.waitForFinished();
     QThreadPool::globalInstance()->setMaxThreadCount(1); // delete those threads
 }
@@ -550,3 +525,5 @@ void KLocalizedStringTest::testLazy()
 }
 
 QTEST_MAIN(KLocalizedStringTest)
+
+#include "moc_klocalizedstringtest.cpp"
