@@ -8,18 +8,15 @@
 #include "isocodes_p.h"
 #include "isocodescache_p.h"
 #include "kcatalog_p.h"
-#include "kcountrysubdivision.h"
 #include "klocalizedstring.h"
 #include "logging.h"
 #include "spatial_index_p.h"
 #include "timezonedata_p.h"
 
-#if QT_VERSION < QT_VERSION_CHECK(6, 2, 0)
-#include <private/qlocale_p.h>
-#endif
-
 #include <cstring>
 
+using namespace Qt::Literals;
+
 static_assert(sizeof(KCountry) == 2);
 
 KCountry::KCountry()
@@ -114,11 +111,7 @@ QLocale::Country KCountry::country() const
         return QLocale::AnyCountry;
     }
 
-#if QT_VERSION >= QT_VERSION_CHECK(6, 2, 0)
     return QLocale::codeToTerritory(alpha2());
-#else
-    return QLocalePrivate::codeToCountry(alpha2());
-#endif
 }
 
 QList<const char *> KCountry::timeZoneIds() const
@@ -278,11 +271,7 @@ KCountry KCountry::fromLocation(float latitude, float longitude)
 
 KCountry KCountry::fromQLocale(QLocale::Country country)
 {
-#if QT_VERSION >= QT_VERSION_CHECK(6, 2, 0)
     return fromAlpha2(QLocale::territoryToCode(country).data());
-#else
-    return fromAlpha2(QLocalePrivate::countryToCode(country).data());
-#endif
 }
 
 static QString normalizeCountryName(QStringView name)
@@ -310,6 +299,9 @@ static QString normalizeCountryName(QStringView name)
         }
 
         if (c.isSpace()) {
+            if (!res.isEmpty() && !res.back().isSpace()) {
+                res.push_back(' '_L1);
+            }
             continue;
         }
 
@@ -322,7 +314,21 @@ static QString normalizeCountryName(QStringView name)
         }
     }
 
-    return res;
+    return res.trimmed();
+}
+
+// check is @p needle is a space-separated substring of haystack
+static bool isSeparatedSubstring(QStringView haystack, QStringView needle)
+{
+    auto idx = haystack.indexOf(needle);
+    if (idx < 0) {
+        return false;
+    }
+    if (idx > 0 && !haystack[idx - 1].isSpace()) {
+        return false;
+    }
+    idx += needle.size();
+    return idx >= haystack.size() || haystack[idx].isSpace();
 }
 
 static void checkSubstringMatch(QStringView lhs, QStringView rhs, uint16_t code, uint16_t &result)
@@ -330,7 +336,8 @@ static void checkSubstringMatch(QStringView lhs, QStringView rhs, uint16_t code,
     if (result == std::numeric_limits<uint16_t>::max() || result == code || rhs.isEmpty()) {
         return;
     }
-    const auto matches = lhs.startsWith(rhs) || rhs.startsWith(lhs) || lhs.endsWith(rhs) || rhs.endsWith(lhs);
+    const auto matches = isSeparatedSubstring(lhs, rhs) || isSeparatedSubstring(rhs, lhs);
+
     if (!matches) {
         return;
     }
@@ -417,3 +424,5 @@ QStringList KCountry::timeZoneIdsStringList() const
     });
     return l;
 }
+
+#include "moc_kcountry.cpp"
